// background.js

chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.action === 'updateIcon') {
    chrome.action.setIcon({ path: { "16": message.iconPath16, "48": message.iconPath48, "128": message.iconPath128 } });
  }
});

chrome.tabs.onActivated.addListener(updateIconForCurrentTab);
chrome.tabs.onUpdated.addListener((tabId, changeInfo, tab) => {
  if (changeInfo.status === 'complete') {
    updateIconForCurrentTab();
  }
});

function updateIconForCurrentTab() {
  chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
    if (tabs[0]) {
      const currentUrl = tabs[0].url;

      fetch(`https://rateandcomment.com/z/index.php?url=${encodeURIComponent(currentUrl)}`)
        .then(response => response.json())
        .then(data => {
          const hasRatings = data.length > 0;
          const iconPaths = hasRatings ? {
            iconPath16: 'icons/icon-active16.png',
            iconPath48: 'icons/icon-active48.png',
            iconPath128: 'icons/icon-active128.png'
          } : {
            iconPath16: 'icons/icon-inactive16.png',
            iconPath48: 'icons/icon-inactive48.png',
            iconPath128: 'icons/icon-inactive128.png'
          };
        })
        .catch(error => {
          console.error('Error fetching data:', error);
        });
    }
  });
}
