document.addEventListener('DOMContentLoaded', () => {
  fetchRatingsAndComments();

  document.getElementById('submit').addEventListener('click', () => {
    const rating = document.getElementById('rating').value;
    const comment = document.getElementById('comment').value;

    if (rating && comment) {
      chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        const currentUrl = tabs[0].url;
        const cleanUrl = currentUrl.endsWith('/') ? currentUrl.slice(0, -1) : currentUrl;

        const data = { rating, comment, url: cleanUrl };

        fetch('https://rateandcomment.com/z/index.php', {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
          body: JSON.stringify(data),
        })
        .then(response => response.json())
        .then(data => {
          if (data.error) {
            alert('Error: ' + data.error);
          } else {
            alert('Data saved successfully');
            fetchRatingsAndComments();
          }
        })
        .catch((error) => {
          console.error('Error:', error);
          alert('An error occurred while saving the data.');
        });
      });
    } else {
      alert('Please fill in both fields.');
    }
  });
});

function fetchRatingsAndComments() {
  chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
    const currentUrl = tabs[0].url;
    const cleanUrl = currentUrl.endsWith('/') ? currentUrl.slice(0, -1) : currentUrl;

    fetch(`https://rateandcomment.com/z/index.php?url=${encodeURIComponent(cleanUrl)}`)
      .then(response => response.json())
      .then(data => {
        const container = document.getElementById('ratings-comments-container');
        container.innerHTML = '';

        if (data.length === 0) {
          container.innerHTML = '<p>No ratings or comments yet.</p>';
          updateIcon(false);
        } else {
          data.forEach(entry => {
            const entryDiv = document.createElement('div');
            entryDiv.className = 'entry';
            entryDiv.innerHTML = `<strong>Rating:</strong> ${entry.rating}<br/><strong>Comment:</strong> ${entry.comment}<br/><small><em>${entry.timestamp}</em></small>`;
            
            if (entry.ip === hashedUserIP) {
              const deleteButton = document.createElement('button');
              deleteButton.textContent = 'Delete';
              deleteButton.addEventListener('click', () => deleteRatingAndComment(cleanUrl));

              entryDiv.appendChild(deleteButton);
            }

            container.appendChild(entryDiv);
          });
          updateIcon(true);
        }
      })
      .catch((error) => {
        console.error('Error:', error);
        const container = document.getElementById('ratings-comments-container');
        container.innerHTML = '<p>Error fetching data.</p>';
      });
  });
}

function deleteRatingAndComment(url) {
  const cleanUrl = url.endsWith('/') ? url.slice(0, -1) : url;

  fetch('https://rateandcomment.com/z/index.php', {
    method: 'DELETE',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({ url: cleanUrl }),
  })
  .then(response => response.json())
  .then(data => {
    if (data.error) {
      alert('Error: ' + data.error);
    } else {
      alert('Data deleted successfully');
      fetchRatingsAndComments();
    }
  })
  .catch((error) => {
    console.error('Error:', error);
    alert('An error occurred while deleting the data.');
  });
}

function updateIcon(hasRatings) {
  const iconPaths = hasRatings ? {
    iconPath16: 'icons/icon-active16.png',
    iconPath48: 'icons/icon-active48.png',
    iconPath128: 'icons/icon-active128.png'
  } : {
    iconPath16: 'icons/icon-inactive16.png',
    iconPath48: 'icons/icon-inactive48.png',
    iconPath128: 'icons/icon-inactive128.png'
  };
  chrome.runtime.sendMessage({ action: 'updateIcon', ...iconPaths });
}

let currentUserIP = '';
let hashedUserIP = '';

// Fetch user IP
fetch('https://api.ipify.org?format=json')
  .then(response => response.json())
  .then(data => {
    currentUserIP = data.ip;
    sha256(currentUserIP).then(hash => {
      hashedUserIP = hash;
      fetchRatingsAndComments();
    });
  })
  .catch(error => {
    console.error('Error fetching user IP:', error);
  });

// SHA-256 hash function
function sha256(message) {
  // Convert string to ArrayBuffer
  const buffer = new TextEncoder('utf-8').encode(message);
  return crypto.subtle.digest('SHA-256', buffer).then(hash => {
    // Convert hash to hex string
    return Array.prototype.map.call(new Uint8Array(hash), x => ('00' + x.toString(16)).slice(-2)).join('');
  });
}
